@@ -1,4 +1,4 @@
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 #
 #   file: lib/Test/Dist/Zilla.pm
 #
@@ -17,7 +17,7 @@
 #   You should have received a copy of the GNU General Public License along with
 #   perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
 #
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 
 #pod =head1 SYNOPSIS
 #pod
@@ -67,7 +67,7 @@ use version 0.77;
 use warnings;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = 'v0.4.2'; # VERSION
+our $VERSION = 'v0.4.2_01'; # TRIAL VERSION
 
 use Dist::Zilla::Tester::DieHard v0.5.0;    # Need `release` method.
 use File::Temp qw{ tempdir };
@@ -102,9 +102,9 @@ use Try::Tiny;
 #pod
 #pod     run_me {
 #pod         dist => {
-#pod             name     => 'Assa',
-#pod             version  => '0.007',
-#pod             author   => 'John Doe',
+#pod             name     => 'Shooba',
+#pod             version  => 'v0.7.0',
+#pod             author   => 'John Doe, Jr.',
 #pod             ...
 #pod         },
 #pod         ...
@@ -195,7 +195,7 @@ sub _build_plugins {
 #pod             '1;',
 #pod         ],
 #pod         'Changes'  => "Release history for Dist-Zilla-Plugin-Assa\n\n",
-#pod         'MANIFEST' => "lib/Assa.pm\nChanges\nMANIFEST\n",
+#pod         'MANIFEST' => [ qw{ lib/Assa.pm Changes MANIFEST } ],
 #pod     } };
 #pod
 #pod     run_me {
@@ -228,7 +228,7 @@ sub _build_files {
 #pod
 #pod By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( ... ) >> with
 #pod appropriate arguments. Thanks to C<Dist::Zilla::Tester::DieHard>, it is never dies even if
-#pod constructing fails, so C<< $self->tzil->log_message >> returns the log messages in anyway.
+#pod constructing fails, so C<< $self->tzil->log_message >> returns the log messages anyway.
 #pod
 #pod Note: Avoid calling C<build> on C<tzil>:
 #pod
@@ -243,13 +243,11 @@ sub _build_files {
 #pod Examples:
 #pod
 #pod     use Path::Tiny;
-#pod     tests 'Check META.json' => sub {
+#pod     test 'Check META.json' => sub {
 #pod         my ( $self ) = @_;
-#pod         if ( $self->exception ) {
-#pod             plan skip_all => 'exception occurred';
-#pod         };
+#pod         $self->skip_if_exception();
 #pod         my $built_in = path( $self->tzil->built_in );
-#pod         my $json = $built_in->child( 'META.json' )->slurp;
+#pod         my $json = $built_in->child( 'META.json' )->slurp_utf8;
 #pod         cmp_deeply( $json, $self->expected->{ json } );
 #pod     };
 #pod
@@ -267,8 +265,14 @@ has tzil => (
 sub _build_tzil {
     my ( $self ) = @_;
     my $files = $self->files;
-    return Builder->from_config(
-        { dist_root => tempdir( CLEANUP => 1 ) },
+    my $tzil = Builder->from_config(
+        {
+            dist_root => tempdir( CLEANUP => 1 ),
+                #   `Dist::Zilla::Tester::_Builder` copies all the files from `dist_root` directory
+                #   to the source directory. We do not have any prepared files, but have to specify
+                #   `dist_root` option because `Dist::Zilla::Tester::_Builder` requires it. Let us
+                #   specify a temporary empty directory.
+        },
         {
             add_files => {
                 'source/dist.ini' => dist_ini(
@@ -295,23 +299,32 @@ sub _build_tzil {
             },
         },
     );
+    return $tzil;
 };
 
 # --------------------------------------------------------------------------------------------------
 
 #pod =method C<build>
 #pod
-#pod The method calls same-name method on C<tzil>, catches exception if any thrown, and saves the caught
-#pod exception in C<exception> attribute for further analysis.
+#pod =method C<release>
 #pod
-#pod Avoid calling C<build> on C<tzil> — some tests may rely on C<build> method modifiers, which are
-#pod applicable to C<< $self->build() >> but not to C<< $self->tzil->build() >>.
+#pod The methods call same-name method on C<tzil>, catch exception if any thrown, and save the caught
+#pod exception in the C<exception> attribute for further analysis.
+#pod
+#pod Avoid calling these methods on C<tzil> — some tests may rely on method modifiers, which are
+#pod applicable to C<< $self->I<method>() >> but not to C<< $self->tzil->I<method>() >>.
 #pod
 #pod Examples:
 #pod
-#pod     test 'Build' => sub {
+#pod     test Build => sub {
 #pod         my ( $self ) = @_;
-#pod         $self->build();
+#pod         $self->build();     # == dzil build
+#pod         ...
+#pod     };
+#pod
+#pod     test Release => sub {
+#pod         my ( $self ) = @_;
+#pod         $self->release();   # == dzil release
 #pod         ...
 #pod     };
 #pod
@@ -332,13 +345,11 @@ around [ qw{ build release } ] => sub {
 
 #pod =attr C<exception>
 #pod
-#pod Exception occurred during build, or C<undef> is no exception were occurred.
+#pod Exception occurred during build, or C<undef> is no exception was occurred.
 #pod
 #pod     test 'Post-build' => sub {
 #pod         my ( $self ) = @_;
-#pod         if ( $self->exception ) {
-#pod             plan skip_all => 'exception thrown';
-#pod         };
+#pod         cmp_deeply( $self->exception, $self->expected->{ exception } );
 #pod         ...
 #pod     };
 #pod
@@ -354,9 +365,9 @@ has exception => (
 
 #pod =attr C<expected>
 #pod
-#pod A hash of expected outcomes. C<Test::Dist::Zilla> itself does use this attribute, but more specific
-#pod roles may do. For example, C<Test::Dizt::Zilla::Build> uses C<exception> and C<messages> keys,
-#pod C<Test::Dizt::Zilla::BuiltFiles> uses C<files> key.
+#pod A hash of expected outcomes. C<Test::Dist::Zilla> itself does not use this attribute, but more
+#pod specific roles may do. For example, C<Test::Dizt::Zilla::Build> uses C<exception> and C<messages>
+#pod keys, C<Test::Dizt::Zilla::BuiltFiles> uses C<files> key.
 #pod
 #pod C<HashRef>, required.
 #pod
@@ -410,11 +421,11 @@ sub messages {
 
 #pod =attr C<message_filter>
 #pod
-#pod If C<message_filter> is defined, it is used by the default C<messages> implementation to filter the
+#pod If C<message_filter> is defined, it is used by default C<messages> implementation to filter the
 #pod actual log messages. C<message_filter> function is called once with list of all the log messages.
 #pod The function is expected to return a list of messages (possibly, grepped and/or edited).
 #pod
-#pod Note: C<message_filter> is a function, not method — C<messages> method does not pass C<$self>
+#pod Note: C<message_filter> value is a function, not method — C<messages> method does not pass C<$self>
 #pod reference to the C<message_filter>.
 #pod
 #pod If C<messages> method is overridden, the attribute may be used or ignored — it depends on new
@@ -454,6 +465,32 @@ sub _build_message_filter {
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =method skip_if_exception
+#pod
+#pod This convenience method makes test routines a bit shorter. Instead of writing
+#pod
+#pod     if ( defined( $self->exception ) ) {
+#pod         plan skip_all => 'exception occurred';
+#pod     };
+#pod
+#pod you can write just
+#pod
+#pod     $self->skip_if_exception;
+#pod
+#pod =cut
+
+sub skip_if_exception {
+    my ( $self ) = @_;
+    if ( defined( $self->exception ) ) {
+        plan skip_all => 'exception occurred';
+    };
+    return;
+};
+
+# --------------------------------------------------------------------------------------------------
+
+# This stuff is not settled down yet.
+
 has _annotation => (
     is      => 'ro',
     isa     => 'Str',
@@ -539,7 +576,8 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.4.2, released on 2015-10-31 08:49 UTC.
+Version v0.4.2_01, released on 2016-11-11 20:48 UTC.
+This is a B<trial release>.
 
 =head1 SYNOPSIS
 
@@ -599,9 +637,9 @@ Examples:
 
     run_me {
         dist => {
-            name     => 'Assa',
-            version  => '0.007',
-            author   => 'John Doe',
+            name     => 'Shooba',
+            version  => 'v0.7.0',
+            author   => 'John Doe, Jr.',
             ...
         },
         ...
@@ -654,7 +692,7 @@ Examples:
             '1;',
         ],
         'Changes'  => "Release history for Dist-Zilla-Plugin-Assa\n\n",
-        'MANIFEST' => "lib/Assa.pm\nChanges\nMANIFEST\n",
+        'MANIFEST' => [ qw{ lib/Assa.pm Changes MANIFEST } ],
     } };
 
     run_me {
@@ -672,7 +710,7 @@ constructing fails).
 
 By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( ... ) >> with
 appropriate arguments. Thanks to C<Dist::Zilla::Tester::DieHard>, it is never dies even if
-constructing fails, so C<< $self->tzil->log_message >> returns the log messages in anyway.
+constructing fails, so C<< $self->tzil->log_message >> returns the log messages anyway.
 
 Note: Avoid calling C<build> on C<tzil>:
 
@@ -687,33 +725,29 @@ See C<build> method description for difference.
 Examples:
 
     use Path::Tiny;
-    tests 'Check META.json' => sub {
+    test 'Check META.json' => sub {
         my ( $self ) = @_;
-        if ( $self->exception ) {
-            plan skip_all => 'exception occurred';
-        };
+        $self->skip_if_exception();
         my $built_in = path( $self->tzil->built_in );
-        my $json = $built_in->child( 'META.json' )->slurp;
+        my $json = $built_in->child( 'META.json' )->slurp_utf8;
         cmp_deeply( $json, $self->expected->{ json } );
     };
 
 =head2 C<exception>
 
-Exception occurred during build, or C<undef> is no exception were occurred.
+Exception occurred during build, or C<undef> is no exception was occurred.
 
     test 'Post-build' => sub {
         my ( $self ) = @_;
-        if ( $self->exception ) {
-            plan skip_all => 'exception thrown';
-        };
+        cmp_deeply( $self->exception, $self->expected->{ exception } );
         ...
     };
 
 =head2 C<expected>
 
-A hash of expected outcomes. C<Test::Dist::Zilla> itself does use this attribute, but more specific
-roles may do. For example, C<Test::Dizt::Zilla::Build> uses C<exception> and C<messages> keys,
-C<Test::Dizt::Zilla::BuiltFiles> uses C<files> key.
+A hash of expected outcomes. C<Test::Dist::Zilla> itself does not use this attribute, but more
+specific roles may do. For example, C<Test::Dizt::Zilla::Build> uses C<exception> and C<messages>
+keys, C<Test::Dizt::Zilla::BuiltFiles> uses C<files> key.
 
 C<HashRef>, required.
 
@@ -731,11 +765,11 @@ Examples:
 
 =head2 C<message_filter>
 
-If C<message_filter> is defined, it is used by the default C<messages> implementation to filter the
+If C<message_filter> is defined, it is used by default C<messages> implementation to filter the
 actual log messages. C<message_filter> function is called once with list of all the log messages.
 The function is expected to return a list of messages (possibly, grepped and/or edited).
 
-Note: C<message_filter> is a function, not method — C<messages> method does not pass C<$self>
+Note: C<message_filter> value is a function, not method — C<messages> method does not pass C<$self>
 reference to the C<message_filter>.
 
 If C<messages> method is overridden, the attribute may be used or ignored — it depends on new
@@ -764,17 +798,25 @@ Drop plugin names from messages:
 
 =head2 C<build>
 
-The method calls same-name method on C<tzil>, catches exception if any thrown, and saves the caught
-exception in C<exception> attribute for further analysis.
+=head2 C<release>
 
-Avoid calling C<build> on C<tzil> — some tests may rely on C<build> method modifiers, which are
-applicable to C<< $self->build() >> but not to C<< $self->tzil->build() >>.
+The methods call same-name method on C<tzil>, catch exception if any thrown, and save the caught
+exception in the C<exception> attribute for further analysis.
+
+Avoid calling these methods on C<tzil> — some tests may rely on method modifiers, which are
+applicable to C<< $self->I<method>() >> but not to C<< $self->tzil->I<method>() >>.
 
 Examples:
 
-    test 'Build' => sub {
+    test Build => sub {
         my ( $self ) = @_;
-        $self->build();
+        $self->build();     # == dzil build
+        ...
+    };
+
+    test Release => sub {
+        my ( $self ) = @_;
+        $self->release();   # == dzil release
         ...
     };
 
@@ -791,6 +833,18 @@ Examples:
 
     cmp_deeply( $self->messages, $self->expected->{ messages } );
 
+=head2 skip_if_exception
+
+This convenience method makes test routines a bit shorter. Instead of writing
+
+    if ( defined( $self->exception ) ) {
+        plan skip_all => 'exception occurred';
+    };
+
+you can write just
+
+    $self->skip_if_exception;
+
 =head1 SEE ALSO
 
 =over 4
