@@ -1,4 +1,4 @@
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 #
 #   file: lib/Test/Dist/Zilla/Build.pm
 #
@@ -17,87 +17,9 @@
 #   You should have received a copy of the GNU General Public License along with
 #   perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
 #
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 
-#pod =head1 SYNOPSIS
-#pod
-#pod     package ManifestTester1;
-#pod
-#pod     use Test::Deep qw{ cmp_deeply re };
-#pod     use Test::More;
-#pod     use Test::Routine;
-#pod     use Test::Routine::Util;
-#pod
-#pod     with 'Test::Dist::Zilla::Build';
-#pod
-#pod     has options => (
-#pod         is          => 'ro',
-#pod         isa         => 'HashRef',
-#pod         default     => sub { {} },
-#pod     );
-#pod
-#pod     sub _build_message_filter {
-#pod         sub { grep( { $_ =~ qr{^\[Manifest\] } } @_ ) };
-#pod     };
-#pod
-#pod     sub _build_plugins {
-#pod         my ( $self ) = @_;
-#pod         [
-#pod             'GatherDir',
-#pod             [ 'Manifest' => $self->options ],
-#pod             'MetaJSON',
-#pod         ];
-#pod     };
-#pod
-#pod     sub _build_files { {
-#pod         'lib/Dummy.pm' => 'package Dummy; 1;',
-#pod     } };
-#pod
-#pod     test 'Manifest' => sub {
-#pod
-#pod         my ( $self ) = @_;
-#pod         my $expected = $self->{ expected };
-#pod
-#pod         if ( $self->exception ) {
-#pod             plan skip_all => 'exception occurred';
-#pod         };
-#pod         if ( not exists( $expected->{ manifest } ) ) {
-#pod             plan skip_all => 'no expected manifest';
-#pod         };
-#pod
-#pod         my $name = $self->options->{ filename };
-#pod         my $built_in = path( $self->tzil->built_in );
-#pod         my @manifest = $built_in->child( $name )->lines;
-#pod         cmp_deeply( \@manifest, $expected->{ manifest } );
-#pod
-#pod     };
-#pod
-#pod     run_me 'Positive test' => {
-#pod         options => {
-#pod             filename => 'Manifest',
-#pod         },
-#pod         expected => {
-#pod             manifest => [
-#pod                 'lib/Dunny.pm',
-#pod                 'MANIFEST',
-#pod                 'META.json',
-#pod             ],
-#pod         },
-#pod     };
-#pod
-#pod     run_me 'Negative test' => {
-#pod         options => {
-#pod             filename => '/dev/null',
-#pod         },
-#pod         expected => {
-#pod             exception => re( qr{^Abort\.\.\.} ),
-#pod             messages => [
-#pod                 '[Manifest] Input file /dev/null is empty',
-#pod             ],
-#pod         },
-#pod     };
-#pod
-#pod     exit( 0 );
+#pod =encoding UTF-8
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -117,7 +39,7 @@ use version 0.77;
 use warnings;
 
 # ABSTRACT: Test your Dist::Zilla plugin in I<build> action
-our $VERSION = 'v0.4.2'; # VERSION
+our $VERSION = 'v0.4.2_01'; # TRIAL VERSION
 
 use Test::Routine;
 
@@ -149,12 +71,12 @@ use Test::More;
 #pod complete successfully (i. e. with no exception), otherwise build is expected to fail with the
 #pod specified exception.
 #pod
-#pod If C<messages> key is not specified, log messages are not checked. Actual log messages retrieved
-#pod with C<messages> method so you can filter them before comparison with expected messages by defining
-#pod C<message_filter> attribute and/or by overriding C<messages> method.
+#pod If C<messages> key is not specified, log messages are not checked. Actual log messages are
+#pod retrieved with C<messages> method so you can filter them before comparison with expected messages
+#pod by defining C<message_filter> attribute and/or by overriding C<messages> method.
 #pod
-#pod Exception (if not C<undef>) and log messages are compared expected counterparts with C<cmp_deeply>
-#pod (from C<Test::Deep> module).
+#pod Exception (if not C<undef>) and log messages are compared with expected counterparts by using
+#pod C<cmp_deeply> (from C<Test::Deep> module).
 #pod
 #pod =cut
 
@@ -188,6 +110,83 @@ test 'Build' => sub {
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =head1 SYNOPSIS
+#pod
+#pod
+#pod
+#pod     # Let's test Manifest Dist::Zilla plugin:
+#pod
+#pod     use strict;
+#pod     use warnings;
+#pod
+#pod     use Path::Tiny;
+#pod     use Test::Deep qw{ cmp_deeply re };
+#pod     use Test::More;
+#pod     use Test::Routine;
+#pod     use Test::Routine::Util;
+#pod
+#pod     with 'Test::Dist::Zilla::Build';
+#pod
+#pod     sub _build_message_filter {
+#pod         return sub {
+#pod             map(
+#pod                 { $_ =~ s{^\[.*?\] }{}; $_; }   # Drop plugin name from messages.
+#pod                 grep( { $_ =~ qr{^\Q[Manifest]\E } } @_ )
+#pod                     # We are interested only in messages printed by the plugin.
+#pod             );
+#pod         };
+#pod     };
+#pod
+#pod     test Manifest => sub {
+#pod         my ( $self ) = @_;
+#pod         my $expected = $self->{ expected };
+#pod         $self->skip_if_exception;
+#pod         if ( not exists( $expected->{ manifest } ) ) {
+#pod             plan skip_all => 'no expected manifest';
+#pod         };
+#pod         my $built_in = path( $self->tzil->built_in );
+#pod         my @manifest = $built_in->child( 'MANIFEST' )->lines( { chomp => 1 } );
+#pod         my $comment = shift( @manifest );
+#pod         like(
+#pod             $comment,
+#pod             qr{
+#pod                 ^ \# \Q This file was automatically generated by \E
+#pod                 Dist::Zilla::Plugin::Manifest
+#pod             }x,
+#pod             'first line is a comment',
+#pod         );
+#pod         cmp_deeply( \@manifest, $expected->{ manifest }, 'manifest body' )
+#pod             or do { diag( "MANIFEST:" ); diag( "    $_" ) for @manifest; };
+#pod     };
+#pod
+#pod     run_me 'Positive test' => {
+#pod         # exception and messages are checked by Build test (defined in
+#pod         # Test::Dist::Zilla::Build), manifest content is checked by
+#pod         # Manifest test defined above.
+#pod         plugins => [                        # Plugins to use.
+#pod             'GatherDir',
+#pod             'Manifest',
+#pod             'MetaJSON',
+#pod         ],
+#pod         files => {                          # Files to add.
+#pod             'lib/Dummy.pm' => 'package Dummy; 1;',
+#pod         },
+#pod         expected => {                       # Expected outcome.
+#pod             # exception is not specified => successful build is expected.
+#pod             messages => [],                 # No messages from the plugin expected.
+#pod             manifest => [                   # Expected content of MANIFEST.
+#pod                 'MANIFEST',
+#pod                 'META.json',
+#pod                 'dist.ini',
+#pod                 'lib/Dummy.pm',
+#pod             ],
+#pod         },
+#pod     };
+#pod
+#pod     done_testing;
+#pod
+#pod
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod =for :list
@@ -222,12 +221,17 @@ Test::Dist::Zilla::Build - Test your Dist::Zilla plugin in I<build> action
 
 =head1 VERSION
 
-Version v0.4.2, released on 2015-10-31 08:49 UTC.
+Version v0.4.2_01, released on 2016-11-11 20:48 UTC.
+This is a B<trial release>.
 
 =head1 SYNOPSIS
 
-    package ManifestTester1;
+    # Let's test Manifest Dist::Zilla plugin:
 
+    use strict;
+    use warnings;
+
+    use Path::Tiny;
     use Test::Deep qw{ cmp_deeply re };
     use Test::More;
     use Test::Routine;
@@ -235,74 +239,63 @@ Version v0.4.2, released on 2015-10-31 08:49 UTC.
 
     with 'Test::Dist::Zilla::Build';
 
-    has options => (
-        is          => 'ro',
-        isa         => 'HashRef',
-        default     => sub { {} },
-    );
-
     sub _build_message_filter {
-        sub { grep( { $_ =~ qr{^\[Manifest\] } } @_ ) };
+        return sub {
+            map(
+                { $_ =~ s{^\[.*?\] }{}; $_; }   # Drop plugin name from messages.
+                grep( { $_ =~ qr{^\Q[Manifest]\E } } @_ )
+                    # We are interested only in messages printed by the plugin.
+            );
+        };
     };
 
-    sub _build_plugins {
-        my ( $self ) = @_;
-        [
-            'GatherDir',
-            [ 'Manifest' => $self->options ],
-            'MetaJSON',
-        ];
-    };
-
-    sub _build_files { {
-        'lib/Dummy.pm' => 'package Dummy; 1;',
-    } };
-
-    test 'Manifest' => sub {
-
+    test Manifest => sub {
         my ( $self ) = @_;
         my $expected = $self->{ expected };
-
-        if ( $self->exception ) {
-            plan skip_all => 'exception occurred';
-        };
+        $self->skip_if_exception;
         if ( not exists( $expected->{ manifest } ) ) {
             plan skip_all => 'no expected manifest';
         };
-
-        my $name = $self->options->{ filename };
         my $built_in = path( $self->tzil->built_in );
-        my @manifest = $built_in->child( $name )->lines;
-        cmp_deeply( \@manifest, $expected->{ manifest } );
-
+        my @manifest = $built_in->child( 'MANIFEST' )->lines( { chomp => 1 } );
+        my $comment = shift( @manifest );
+        like(
+            $comment,
+            qr{
+                ^ \# \Q This file was automatically generated by \E
+                Dist::Zilla::Plugin::Manifest
+            }x,
+            'first line is a comment',
+        );
+        cmp_deeply( \@manifest, $expected->{ manifest }, 'manifest body' )
+            or do { diag( "MANIFEST:" ); diag( "    $_" ) for @manifest; };
     };
 
     run_me 'Positive test' => {
-        options => {
-            filename => 'Manifest',
+        # exception and messages are checked by Build test (defined in
+        # Test::Dist::Zilla::Build), manifest content is checked by
+        # Manifest test defined above.
+        plugins => [                        # Plugins to use.
+            'GatherDir',
+            'Manifest',
+            'MetaJSON',
+        ],
+        files => {                          # Files to add.
+            'lib/Dummy.pm' => 'package Dummy; 1;',
         },
-        expected => {
-            manifest => [
-                'lib/Dunny.pm',
+        expected => {                       # Expected outcome.
+            # exception is not specified => successful build is expected.
+            messages => [],                 # No messages from the plugin expected.
+            manifest => [                   # Expected content of MANIFEST.
                 'MANIFEST',
                 'META.json',
+                'dist.ini',
+                'lib/Dummy.pm',
             ],
         },
     };
 
-    run_me 'Negative test' => {
-        options => {
-            filename => '/dev/null',
-        },
-        expected => {
-            exception => re( qr{^Abort\.\.\.} ),
-            messages => [
-                '[Manifest] Input file /dev/null is empty',
-            ],
-        },
-    };
-
-    exit( 0 );
+    done_testing;
 
 =head1 DESCRIPTION
 
@@ -335,12 +328,12 @@ If C<exception> key is not specified (or exception value is C<undef>), build is
 complete successfully (i. e. with no exception), otherwise build is expected to fail with the
 specified exception.
 
-If C<messages> key is not specified, log messages are not checked. Actual log messages retrieved
-with C<messages> method so you can filter them before comparison with expected messages by defining
-C<message_filter> attribute and/or by overriding C<messages> method.
+If C<messages> key is not specified, log messages are not checked. Actual log messages are
+retrieved with C<messages> method so you can filter them before comparison with expected messages
+by defining C<message_filter> attribute and/or by overriding C<messages> method.
 
-Exception (if not C<undef>) and log messages are compared expected counterparts with C<cmp_deeply>
-(from C<Test::Deep> module).
+Exception (if not C<undef>) and log messages are compared with expected counterparts by using
+C<cmp_deeply> (from C<Test::Deep> module).
 
 =head1 SEE ALSO
 
